bl_info = {
    "name": "Handle Coordinate Exporter",
    "author": "Your Name",
    "version": (1, 0),
    "blender": (2, 80, 0),
    "location": "View3D > Tool",
    "description": "Export coordinates of objects containing 'HANDLE' in their name",
    "category": "Object",
}

import bpy
import os
import csv

class ExportHandleCoordinates(bpy.types.Operator):
    bl_idname = "export.handle_coordinates"
    bl_label = "炯眼导出Handle参数"
    bl_options = {'REGISTER', 'UNDO'}
    
    # 添加文件选择器属性
    filepath: bpy.props.StringProperty(
        name="保存位置",
        description="选择保存CSV文件的位置",
        default="",
        maxlen=1024,
        subtype='FILE_PATH'
    )
    
    # 添加文件过滤器
    filter_glob: bpy.props.StringProperty(
        default='*.csv',
        options={'HIDDEN'}
    )

    def invoke(self, context, event):
        # 打开文件选择对话框
        context.window_manager.fileselect_add(self)
        return {'RUNNING_MODAL'}

    def execute(self, context):
        handles = [obj for obj in bpy.data.objects if "HANDLE" in obj.name]
        if not handles:
            self.report({'INFO'}, "No objects containing 'HANDLE' found")
            return {'CANCELLED'}
        
        # 使用用户选择的文件路径
        output_path = self.filepath
        if not output_path.lower().endswith('.csv'):
            output_path += '.csv'
            
        try:
            with open(output_path, 'w', newline='') as csvfile:
                writer = csv.writer(csvfile)
                writer.writerow(["Image Name", "Object Name", "X (cm)", "Y (cm)平台为Z数值", "Z Rotation (deg)"])
                
                for obj in handles:
                    loc = obj.location
                    rot = obj.rotation_euler
                    image_name = obj.name.split('_HANDLE')[0] + '.jpg'
                    writer.writerow([
                        image_name,
                        obj.name,
                        loc.x * 100,
                        loc.z * 100,
                        rot.z * 180 / 3.14159
                    ])

            self.report({'INFO'}, f"Exported {len(handles)} coordinates to {output_path}")
            return {'FINISHED'}
            
        except Exception as e:
            self.report({'ERROR'}, f"保存文件时出错: {str(e)}")
            return {'CANCELLED'}

class HandleExportPanel(bpy.types.Panel):
    bl_label = "Handle Exporter"
    bl_idname = "OBJECT_PT_handle_export"
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_category = "Tool"

    def draw(self, context):
        layout = self.layout
        layout.operator("export.handle_coordinates")

def register():
    bpy.utils.register_class(ExportHandleCoordinates)
    bpy.utils.register_class(HandleExportPanel)

def unregister():
    bpy.utils.unregister_class(ExportHandleCoordinates)
    bpy.utils.unregister_class(HandleExportPanel)

if __name__ == "__main__":
    register()